@@ -1,4 +1,4 @@
-from ngobot_json.response import Response
+from src.response import Response
 
 response = Response()
 print(response.Success())
\ No newline at end of file
